In order to group hospital inpatient admissions into human readable groups, a lookup table has been created. These work with Hospital Episode Statistics (HES) and Secondary Use Services (SUS) data with the admission_method fields.
group_inpatient_admission_methodthe admission_method code
the admission_method grouping as a human readable string