Learn R Programming

epidm (version 1.0.6)

group_inpatient_discharge_destination: Inpatient discharge destination

Description

In order to group hospital inpatient discharge destination into human readable groups, a lookup table has been created. These work with Hospital Episode Statistics (HES) and Secondary Use Services (SUS) data with the discharge_destination fields.

Usage

group_inpatient_discharge_destination

Arguments

Format

code

the discharge_destination code

discharge_destination

the discharge_destination grouping as a human readable string