Learn R Programming

epidm (version 1.0.6)

lab_data: Synthetic Lab Data for epidm

Description

A dataset containing synthetic lab data for testing epidemiological data transformation functions.

A dataset containing synthetic lab data for testing epidemiological data transformation functions.

Usage

data(lab_data)

data(lab_data)

Arguments

Format

A data frame with the following columns:

nhs_number

NHS number

local_patient_identifier

Patient identifier such as hospital number

patient_birth_date

Date of birth of the patients.

sex

Gender of the patients (Factor with levels: "Female", "Male").

surname

Patient surname

forename

Patient forename

organism_species_name

Organism species name (Factor with levels: "KLEBSIELLA PNEUMONIAE").

specimen_date

Date of specimen collection.

specimen_type

Type of specimen: BLOOD or URINE.

lab_code

Laboratory codes (Factor with unique levels).

local_authority_name

Name of the local authority.

local_authority_code

Code of the local authority.

postcode

Postcode

A data frame with the following columns:

nhs_number

NHS number

local_patient_identifier

Patient identifier such as hospital number

patient_birth_date

Date of birth of the patients.

sex

Gender of the patients (Factor with levels: "Female", "Male").

surname

Patient surname

forename

Patient forename

organism_species_name

Organism species name (Factor with levels: "KLEBSIELLA PNEUMONIAE").

specimen_date

Date of specimen collection.

specimen_type

Type of specimen: BLOOD or URINE.

lab_code

Laboratory codes (Factor with unique levels).

local_authority_name

Name of the local authority.

local_authority_code

Code of the local authority.

postcode

Postcode

Examples

Run this code
data(lab_data)
head(lab_data)

data(lab_data)
head(lab_data)

Run the code above in your browser using DataLab