In order to group A&E discharge destination from SNOWMED into human readable groups, a lookup table has been created. These work with Emergency Care Dataset (ECDS) data with the destination_code field to show where a patient goes after discharge from A&E.
group_ecds_discharge_destinationthe ECDS destination_code
the destination grouping as a human readable string