In order to group hospital inpatient discharge destination into human readable groups, a lookup table has been created. These work with Hospital Episode Statistics (HES) and Secondary Use Services (SUS) data with the discharge_destination fields.
group_inpatient_discharge_destinationthe discharge_destination code
the discharge_destination grouping as a human readable string