A dataset containing synthetic lab data for testing epidemiological data transformation functions.
A dataset containing synthetic lab data for testing epidemiological data transformation functions.
data(lab_data)data(lab_data)
A data frame with the following columns:
NHS number
Patient identifier such as hospital number
Date of birth of the patients.
Gender of the patients (Factor with levels: "Female", "Male").
Patient surname
Patient forename
Organism species name (Factor with levels: "KLEBSIELLA PNEUMONIAE").
Date of specimen collection.
Type of specimen: BLOOD or URINE.
Laboratory codes (Factor with unique levels).
Name of the local authority.
Code of the local authority.
Postcode
A data frame with the following columns:
NHS number
Patient identifier such as hospital number
Date of birth of the patients.
Gender of the patients (Factor with levels: "Female", "Male").
Patient surname
Patient forename
Organism species name (Factor with levels: "KLEBSIELLA PNEUMONIAE").
Date of specimen collection.
Type of specimen: BLOOD or URINE.
Laboratory codes (Factor with unique levels).
Name of the local authority.
Code of the local authority.
Postcode
data(lab_data)
head(lab_data)
data(lab_data)
head(lab_data)
Run the code above in your browser using DataLab